

# skrypt oblicza prognozę stopy bezrobocia dla Poznania i powiatu poznańskiego
# w perspektywie t+12 miesięcy. Do działania potrzebny plik M$ Excella z danymi
# empirycznymi oraz wskazane poniżej biblioteki.

# wczytaj bibliotekę umożliwiającą import danych w formacie M$ Excell
library(openxlsx)
data <- read.xlsx('C:/Users/zasada/Desktop/FLESZ OGiRPAP/df_201703.xlsx')

# rozdziel dane na dwa szeregi czasowe: miasto i powiat
powiat <- ts(data$powiat, start = c(2004, 1), frequency = 12)
miasto <- ts(data$miasto, start = c(2004, 1), frequency = 12)

# wczytaj bibiliotekę z narzędziami prognostycznymi
require(forecast)

# określ horyzont czasowy prognozy; w tym przypadku 12 miesięcy
horizon <- 12

# estymacja modelu dla powiatu poznańskiego
fit.arima <- auto.arima(powiat, stationary=TRUE, xreg=fourier(powiat, K=4))
fc.arima <- forecast(fit.arima, xreg=fourier(powiat, K=4, horizon))

# stwórz wykres dla powiatu poznańskiego

maxx <- max(time(powiat)) + 1
minx <- min(time(powiat))

png(filename="powiat.png")
plot(fc.arima, ylab="Stopa bezrobocia", xlab="Czas", xaxt="n")
axis(1, cex.axis=0.8, at=minx:maxx)
grid()
abline(h=mean(powiat), col="red", lty=2)
text(2010, mean(powiat), "srednia", pos=4, col="black", cex=0.75)
dev.off()

# estymacja modelu dla miasta Poznania
fit.arima.city <- auto.arima(miasto, stationary=FALSE, xreg=fourier(miasto, K=4))
fc.arima.city <- forecast(fit.arima.city, xreg=fourier(miasto, K=4, horizon))

# stwórz wykres dla miasta Poznania
png(filename="miasto.png")
plot(fc.arima.city, cex.lab=3, ylab="Stopa bezrobocia", xlab="Czas", xaxt="n")
axis(1, cex.axis=0.8, at=minx:maxx)
grid()
abline(h=mean(miasto), col="red", lty=2)
text(2010, mean(miasto), "srednia", pos=4, col="black", cex=0.75)
dev.off()

# utwórz macierz z danymi
dffcpowiat <- data.frame(fc.arima)
dffcmiasto <- data.frame(fc.arima.city)

# deaktywuj zmienną systemową JAVA_HOME
if (Sys.getenv("JAVA_HOME")!="")
  Sys.setenv(JAVA_HOME="")

# ustaw zmienną systemową R_ZIPCMD aby zapisać plik w formacie M$ Excell
Sys.setenv("R_ZIPCMD" = "C:/Rtools/bin/zip.exe")

# wczytaj biblioteki niezbędne do eksportu danych
library(rJava)
# alternatywny pakiet do importu excella
# require(xlsx)

# zapisz dane na dysku
write.xlsx(dffcpowiat, "powiat.xlsx")
write.xlsx(dffcmiasto, "miasto.xlsx")


hist(powiat, col="blue")
curve(dnorm(x, mean = mean(powiat), sd = sd(powiat)), add = T, lwd=2, col="red")
lines(density(powiat))
